==> ds_caselaw_marklogic_api_client-9.0.0.tar.gz: ds_caselaw_marklogic_api_client-9.0.0/src/caselawclient/responses/search_response.py <==
from typing import List

from lxml import etree

from caselawclient.responses.search_result import SearchResult


class SearchResponse:
    """
    Represents a search response obtained from XML data.

    Attributes:
        NAMESPACES (dict): Namespaces used in XPath expressions.
    """

    NAMESPACES = {"search": "http://marklogic.com/appservices/search"}

    def __init__(self, node: etree._Element):
        """
        Initializes a SearchResponse instance from an xml node.

        Args:
            node (etree._Element): The XML data as an etree element.
        """
        self.node = node

    @staticmethod
    def from_response_string(xml: str) -> "SearchResponse":
        """
        Constructs a SearchResponse instance from an xml response string.

        Args:
            xml (str): The XML data as a string.
        """
        return SearchResponse(etree.fromstring(xml))

    @property
    def total(self) -> str:
        """
        Property: The total number of search results.

        Returns:
            str: The total number of search results.
        """
        return str(
            self.node.xpath("//search:response/@total", namespaces=self.NAMESPACES)[0]
        )

    @property
    def results(self) -> List[SearchResult]:
        """
        Property: Converts the SearchResponse to a list of SearchResult objects.

        Returns:
            List[SearchResult]: The list of search results.
        """
        results = self.node.xpath(
            "//search:response/search:result", namespaces=self.NAMESPACES
        )
        return [
            SearchResult(
                result,
            )
            for result in results
        ]

==> ds_caselaw_marklogic_api_client-14.0.2.tar.gz: ds_caselaw_marklogic_api_client-14.0.2/src/caselawclient/responses/search_response.py <==
from typing import List

from lxml import etree

from caselawclient.responses.search_result import SearchResult


class SearchResponse:
    """
    Represents a search response obtained from XML data.
    """

    NAMESPACES = {"search": "http://marklogic.com/appservices/search"}
    """ Namespaces used in XPath expressions."""

    def __init__(self, node: etree._Element) -> None:
        """
        Initializes a SearchResponse instance from an xml node.

        :param node: The XML data as an etree element
        """
        self.node = node

    @staticmethod
    def from_response_string(xml: str) -> "SearchResponse":
        """
        Constructs a SearchResponse instance from an xml response string.

        :param xml: The XML data as a string
        """
        return SearchResponse(etree.fromstring(xml))

    @property
    def total(self) -> str:
        """
        The total number of search results.

        :return: The total number of search results
        """
        return str(
            self.node.xpath("//search:response/@total", namespaces=self.NAMESPACES)[0]
        )

    @property
    def results(self) -> List[SearchResult]:
        """
        Converts the SearchResponse to a list of SearchResult objects.

        :return: The list of search results
        """
        results = self.node.xpath(
            "//search:response/search:result", namespaces=self.NAMESPACES
        )
        return [
            SearchResult(
                result,
            )
            for result in results
        ]
